"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.IndexManager = void 0;
var _IndexSettingsManager = require("./IndexSettingsManager");
var _DisableIndexing = require("./DisableIndexing");
var _EnableIndexing = require("./EnableIndexing");
var _utils = require("@webiny/utils");
const defaultIndexSettings = {
  numberOfReplicas: 1,
  refreshInterval: "1s"
};
class IndexManager {
  get settings() {
    return this._settings;
  }
  constructor(client, settings, defaults) {
    const indexSettings = new _IndexSettingsManager.IndexSettingsManager(client);
    this.client = client;
    this.disable = new _DisableIndexing.DisableIndexing(indexSettings);
    this.enable = new _EnableIndexing.EnableIndexing(indexSettings);
    this._settings = settings;
    this.defaults = {
      refreshInterval: defaults?.refreshInterval || defaultIndexSettings.refreshInterval,
      numberOfReplicas: defaults?.numberOfReplicas || defaultIndexSettings.numberOfReplicas
    };
  }
  async list() {
    try {
      const response = await this.client.cat.indices({
        format: "json"
      });
      if (!Array.isArray(response.body)) {
        return [];
      }
      return response.body.map(item => item.index).filter(Boolean);
    } catch (ex) {
      console.error(JSON.stringify({
        message: "Failed to list indices.",
        error: (0, _utils.getObjectProperties)(ex)
      }));
      return [];
    }
  }
  async disableIndexing(index) {
    /**
     * No need to disable indexing if it's already disabled.
     */
    if (this._settings[index]) {
      return this._settings[index];
    }
    const settings = await this.disable.exec(index);
    this._settings[index] = settings;
    return settings;
  }
  async enableIndexing(index) {
    if (!index) {
      const indexes = Object.keys(this._settings);
      for (const index of indexes) {
        await this.enableIndexing(index);
      }
      return;
    }
    const settings = this._settings[index] || this.defaults;
    await this.enable.exec(index, settings);
  }
  async createIndex(index, settings) {
    await this.client.indices.create({
      index,
      body: settings
    });
  }
  async indexExists(index) {
    const response = await this.client.indices.exists({
      index,
      ignore_unavailable: false,
      allow_no_indices: true,
      include_defaults: true,
      flat_settings: false,
      local: false
    });
    return !!response.body;
  }
}
exports.IndexManager = IndexManager;

//# sourceMappingURL=IndexManager.js.map